==> owncloud_7.0.4+dfsg.orig.tar.bz2: owncloud/core/l10n/pt_PT.php <==
<?php
$TRANSLATIONS = array(
"Expiration date is in the past." => "A data de expiração é no passado.",
"Couldn't send mail to following users: %s " => "Não conseguiu enviar correio aos seguintes utilizadores: %s",
"Turned on maintenance mode" => "Activado o modo de manutenção",
"Turned off maintenance mode" => "Desactivado o modo de manutenção",
"Updated database" => "Base de dados actualizada",
"Checked database schema update" => "Atualização do esquema da base de dados verificada.",
"Disabled incompatible apps: %s" => "Apps incompatíveis desativadas: %s",
"No image or file provided" => "Não foi selecionado nenhum ficheiro para importar",
"Unknown filetype" => "Ficheiro desconhecido",
"Invalid image" => "Imagem inválida",
"No temporary profile picture available, try again" => "Foto temporária de perfil indisponível, tente novamente",
"No crop data provided" => "Sem dados de corte fornecidos",
"Sunday" => "Domingo",
"Monday" => "Segunda",
"Tuesday" => "Terça",
"Wednesday" => "Quarta",
"Thursday" => "Quinta",
"Friday" => "Sexta",
"Saturday" => "Sábado",
"January" => "Janeiro",
"February" => "Fevereiro",
"March" => "Março",
"April" => "Abril",
"May" => "Maio",
"June" => "Junho",
"July" => "Julho",
"August" => "Agosto",
"September" => "Setembro",
"October" => "Outubro",
"November" => "Novembro",
"December" => "Dezembro",
"Settings" => "Configurações",
"File" => "Ficheiro",
"Folder" => "Pasta",
"Image" => "Imagem",
"Audio" => "Audio",
"Saving..." => "A guardar...",
"seconds ago" => "Minutos atrás",
"_%n minute ago_::_%n minutes ago_" => array("%n minuto atrás","%n minutos atrás"),
"_%n hour ago_::_%n hours ago_" => array("%n hora atrás","%n horas atrás"),
"today" => "hoje",
"yesterday" => "ontem",
"_%n day ago_::_%n days ago_" => array("%n dia atrás","%n dias atrás"),
"last month" => "ultímo mês",
"_%n month ago_::_%n months ago_" => array("%n mês atrás","%n meses atrás"),
"last year" => "ano passado",
"years ago" => "anos atrás",
"Couldn't send reset email. Please contact your administrator." => "Ocorreu um problema com o envio do e-mail, por favor contactar o administrador.",
"The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." => "O link para fazer reset à sua password foi enviado para o seu e-mail. <br> Se não o recebeu dentro um espaço de tempo aceitável, por favor verifique a sua pasta de SPAM.<br> Se não o encontrar, por favor contacte o seu administrador.",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" => "Os seus ficheiros estão encriptados. Se não activou a chave de recuperação, não vai ser possível recuperar os seus dados no caso da sua password ser reinicializada. Se não tem a certeza do que precisa de fazer, por favor contacte o seu administrador antes de continuar. Tem a certeza que quer continuar?",
"I know what I'm doing" => "Tenho a certeza",
"Reset password" => "Repor password",
"Password can not be changed. Please contact your administrator." => "A password não pode ser alterada. Contacte o seu administrador.",
"Yes" => "Sim",
"No" => "Não",
"Choose" => "Escolha",
"Error loading file picker template: {error}" => "Erro ao carregar o modelo de selecionador de ficheiro: {error}",
"Ok" => "Ok",
"Error loading message template: {error}" => "Erro ao carregar o template: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} conflicto de ficheiro","{count} conflitos de ficheiro"),
"One file conflict" => "Um conflito no ficheiro",
"New Files" => "Ficheiros Novos",
"Already existing files" => "Ficheiro já existente",
"Which files do you want to keep?" => "Quais os ficheiros que pretende manter?",
"If you select both versions, the copied file will have a number added to its name." => "Se escolher ambas as versões, o ficheiro copiado irá ter um número adicionado ao seu nome.",
"Cancel" => "Cancelar",
"Continue" => "Continuar",
"(all selected)" => "(todos seleccionados)",
"({count} selected)" => "({count} seleccionados)",
"Error loading file exists template" => "Erro ao carregar o modelo de existências do ficheiro",
"Very weak password" => "Password muito fraca",
"Weak password" => "Password fraca",
"So-so password" => "Password aceitável",
"Good password" => "Password Forte",
"Strong password" => "Password muito forte",
"Shared" => "Partilhado",
"Shared by {owner}" => "Partilhado por {owner}",
"Shared with {recipients}" => "Partilhado com {recipients}",
"Share" => "Partilhar",
"Error" => "Erro",
"Error while sharing" => "Erro ao partilhar",
"Error while unsharing" => "Erro ao deixar de partilhar",
"Error while changing permissions" => "Erro ao mudar permissões",
"Shared with you and the group {group} by {owner}" => "Partilhado consigo e com o grupo {group} por {owner}",
"Shared with you by {owner}" => "Partilhado consigo por {owner}",
"Share with user or group …" => "Partilhar com utilizador ou grupo...",
"Share link" => "Partilhar o link",
"The public link will expire no later than {days} days after it is created" => "O link público expira, o mais tardar {days} dias após sua criação",
"By default the public link will expire after {days} days" => "Por defeito, o link publico irá expirar depois de {days} dias",
"Password protect" => "Proteger com palavra-passe",
"Choose a password for the public link" => "Defina a palavra-passe para o link público",
"Allow Public Upload" => "Permitir Envios Públicos",
"Email link to person" => "Enviar o link por e-mail",
"Send" => "Enviar",
"Set expiration date" => "Especificar data de expiração",
"Expiration date" => "Data de expiração",
"Share via email:" => "Partilhar via email:",
"No people found" => "Não foi encontrado ninguém",
"group" => "grupo",
"Resharing is not allowed" => "Não é permitido partilhar de novo",
"Shared in {item} with {user}" => "Partilhado em {item} com {user}",
"Unshare" => "Deixar de partilhar",
"notify by email" => "Notificar por email",
"can share" => "pode partilhar",
"can edit" => "pode editar",
"access control" => "Controlo de acesso",
"create" => "criar",
"update" => "actualizar",
"delete" => "apagar",
"Password protected" => "Protegido com palavra-passe",
"Error unsetting expiration date" => "Erro ao retirar a data de expiração",
"Error setting expiration date" => "Erro ao aplicar a data de expiração",
"Sending ..." => "A Enviar...",
"Email sent" => "E-mail enviado",
"Warning" => "Aviso",
"The object type is not specified." => "O tipo de objecto não foi especificado",
"Enter new" => "Introduza novo",
"Delete" => "Eliminar",
"Add" => "Adicionar",
"Edit tags" => "Editar etiquetas",
"Error loading dialog template: {error}" => "Erro ao carregar modelo de diálogo: {error}",
"No tags selected for deletion." => "Não foram escolhidas etiquetas para apagar.",
"Updating {productName} to version {version}, this may take a while." => "A atualizar {productName} para a versão {version}, isto poderá demorar algum tempo.",
"Please reload the page." => "Por favor recarregue a página.",
"The update was unsuccessful." => "Não foi possível atualizar.",
"The update was successful. Redirecting you to ownCloud now." => "A actualização foi concluída com sucesso. Vai ser redireccionado para o ownCloud agora.",
"Couldn't reset password because the token is invalid" => "É impossível efetuar reset à password. ",
"Couldn't send reset email. Please make sure your username is correct." => "Ocorreu um problema com o envio do e-mail, por favor confirme o seu utilizador.",
"Couldn't send reset email because there is no email address for this username. Please contact your administrator." => "Ocorreu um problema com o envio do e-mail, por favor contacte o administrador.",
"%s password reset" => "%s reposição da password",
"Use the following link to reset your password: {link}" => "Use o seguinte endereço para repor a sua password: {link}",
"You will receive a link to reset your password via Email." => "Vai receber um endereço para repor a sua password",
"Username" => "Nome de utilizador",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" => "Os seus ficheiros estão encriptados. Se não activou a chave de recuperação, não vai ser possível recuperar os seus dados no caso da sua password ser reinicializada. Se não tem a certeza do que precisa de fazer, por favor contacte o seu administrador antes de continuar. Tem a certeza que quer continuar?",
"Yes, I really want to reset my password now" => "Sim, tenho a certeza que pretendo redefinir a minha palavra-passe agora.",
"Reset" => "Repor",
"New password" => "Nova palavra-chave",
"New Password" => "Nova password",
"Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " => "Esta plataforma não suporta o sistema operativo Mac OS X e o %s poderá não funcionar correctamente. Utilize por sua conta e risco.",
"For the best results, please consider using a GNU/Linux server instead." => "Para um melhor resultado, utilize antes o servidor GNU/Linux.",
"Personal" => "Pessoal",
"Users" => "Utilizadores",
"Apps" => "Aplicações",
"Admin" => "Admin",
"Help" => "Ajuda",
"Error loading tags" => "Erro ao carregar etiquetas",
"Tag already exists" => "A etiqueta já existe",
"Error deleting tag(s)" => "Erro ao apagar etiqueta(s)",
"Error tagging" => "Erro ao etiquetar",
"Error untagging" => "Erro ao desetiquetar",
"Error favoriting" => "Erro a definir como favorito",
"Error unfavoriting" => "Erro a remover como favorito",
"Access forbidden" => "Acesso interdito",
"Cloud not found" => "Cloud nao encontrada",
"Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" => "Olá,\n\napenas para informar que %s partilhou »%s« consigo.\nConsulte aqui: %s\n",
"The share will expire on %s." => "Esta partilha vai expirar em %s.",
"Cheers!" => "Parabéns!",
"Security Warning" => "Aviso de Segurança",
"Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" => "A sua versão do PHP é vulnerável ao ataque Byte Null (CVE-2006-7243)",
"Please update your PHP installation to use %s securely." => "Por favor atualize a sua versão PHP instalada para usar o %s com segurança.",
"No secure random number generator is available, please enable the PHP OpenSSL extension." => "Não existe nenhum gerador seguro de números aleatórios, por favor, active a extensão OpenSSL no PHP.",
"Without a secure random number generator an attacker may be able to predict password reset tokens and take over your account." => "Sem nenhum gerador seguro de números aleatórios, uma pessoa mal intencionada pode prever a sua password, reiniciar as seguranças adicionais e tomar conta da sua conta. ",
"Your data directory and files are probably accessible from the internet because the .htaccess file does not work." => "A pasta de dados do ownCloud e os respectivos ficheiros, estarão provavelmente acessíveis a partir da internet, pois o ficheiros .htaccess não funciona.",
"For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." => "Para obter informações de como configurar correctamente o servidor, veja em: <a href=\"%s\" target=\"_blank\">documentação</a>.",
"Create an <strong>admin account</strong>" => "Criar uma <strong>conta administrativa</strong>",
"Password" => "Password",
"Storage & database" => "Armazenamento e base de dados",
"Data folder" => "Pasta de dados",
"Configure the database" => "Configure a base de dados",
"Only %s is available." => "Apenas %s está disponível.",
"Database user" => "Utilizador da base de dados",
"Database password" => "Password da base de dados",
"Database name" => "Nome da base de dados",
"Database tablespace" => "Tablespace da base de dados",
"Database host" => "Anfitrião da base de dados",
"SQLite will be used as database. For larger installations we recommend to change this." => "Será usado SQLite como base de dados. Para instalações maiores é recomendável a sua alteração.",
"Finish setup" => "Acabar instalação",
"Finishing …" => "A terminar...",
"This application requires JavaScript to be enabled for correct operation.  Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and re-load this interface." => "Esta aplicação requer JavaScript ativado para uma operação correta. Por favor <a href=\"http://enable-javascript.com/\" target=\"_blank\">ative o JavaScript</a> e recarregue esta interface.",
"%s is available. Get more information on how to update." => "%s está disponível. Tenha mais informações como actualizar.",
"Log out" => "Sair",
"Automatic logon rejected!" => "Login automático rejeitado!",
"If you did not change your password recently, your account may be compromised!" => "Se não mudou a sua palavra-passe recentemente, a sua conta pode ter sido comprometida!",
"Please change your password to secure your account again." => "Por favor mude a sua palavra-passe para assegurar a sua conta de novo.",
"Server side authentication failed!" => "Autenticação do lado do servidor falhou!",
"Please contact your administrator." => "Por favor contacte o administrador.",
"Forgot your password? Reset it!" => "Esqueceu-se da password? Recupere-a!",
"remember" => "lembrar",
"Log in" => "Entrar",
"Alternative Logins" => "Contas de acesso alternativas",
"Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" => "Olá,<br><br>apenas para informar que %s partilhou <strong>%s</strong> consigo.<br><a href=\"%s\">Consulte aqui!</a><br><br>",
"This ownCloud instance is currently in single user mode." => "Esta instância do ownCloud está actualmente configurada no modo de utilizador único.",
"This means only administrators can use the instance." => "Isto significa que apenas os administradores podem usar a instância.",
"Contact your system administrator if this message persists or appeared unexpectedly." => "Contacte o seu administrador de sistema se esta mensagem continuar a aparecer ou apareceu inesperadamente.",
"Thank you for your patience." => "Obrigado pela sua paciência.",
"%s will be updated to version %s." => "O %s irá ser atualizado para a versão %s.",
"The following apps will be disabled:" => "As seguintes apps irão ser desativadas:",
"The theme %s has been disabled." => "O tema %s foi desativado.",
"Please make sure that the database, the config folder and the data folder have been backed up before proceeding." => "Por favor garanta a cópia de segurança da base de dados e das pastas 'config' e 'data' antes de prosseguir.",
"Start update" => "Iniciar atualização",
"This ownCloud instance is currently being updated, which may take a while." => "Esta instância do ownCloud está a ser actualizada, poderá demorar algum tempo.",
"Please reload this page after a short time to continue using ownCloud." => "Por favo recarregue esta página após algum tempo para continuar a usar ownCloud."
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.13~dfsg.orig.tar.bz2: owncloud/core/l10n/pt_PT.php <==
<?php
$TRANSLATIONS = array(
"Expiration date is in the past." => "A data de expiração é no passado.",
"Couldn't send mail to following users: %s " => "Não conseguiu enviar correio aos seguintes utilizadores: %s",
"Turned on maintenance mode" => "Activado o modo de manutenção",
"Turned off maintenance mode" => "Desactivado o modo de manutenção",
"Updated database" => "Base de dados actualizada",
"Checked database schema update" => "Atualização do esquema da base de dados verificada.",
"Disabled incompatible apps: %s" => "Apps incompatíveis desativadas: %s",
"No image or file provided" => "Não foi selecionado nenhum ficheiro para importar",
"Unknown filetype" => "Ficheiro desconhecido",
"Invalid image" => "Imagem inválida",
"No temporary profile picture available, try again" => "Foto temporária de perfil indisponível, tente novamente",
"No crop data provided" => "Sem dados de corte fornecidos",
"Sunday" => "Domingo",
"Monday" => "Segunda",
"Tuesday" => "Terça",
"Wednesday" => "Quarta",
"Thursday" => "Quinta",
"Friday" => "Sexta",
"Saturday" => "Sábado",
"January" => "Janeiro",
"February" => "Fevereiro",
"March" => "Março",
"April" => "Abril",
"May" => "Maio",
"June" => "Junho",
"July" => "Julho",
"August" => "Agosto",
"September" => "Setembro",
"October" => "Outubro",
"November" => "Novembro",
"December" => "Dezembro",
"Settings" => "Configurações",
"File" => "Ficheiro",
"Folder" => "Pasta",
"Image" => "Imagem",
"Audio" => "Audio",
"Saving..." => "A guardar...",
"seconds ago" => "Minutos atrás",
"_%n minute ago_::_%n minutes ago_" => array("%n minuto atrás","%n minutos atrás"),
"_%n hour ago_::_%n hours ago_" => array("%n hora atrás","%n horas atrás"),
"today" => "hoje",
"yesterday" => "ontem",
"_%n day ago_::_%n days ago_" => array("%n dia atrás","%n dias atrás"),
"last month" => "ultímo mês",
"_%n month ago_::_%n months ago_" => array("%n mês atrás","%n meses atrás"),
"last year" => "ano passado",
"years ago" => "anos atrás",
"Couldn't send reset email. Please contact your administrator." => "Ocorreu um problema com o envio do e-mail, por favor contactar o administrador.",
"The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." => "O link para fazer reset à sua password foi enviado para o seu e-mail. <br> Se não o recebeu dentro um espaço de tempo aceitável, por favor verifique a sua pasta de SPAM.<br> Se não o encontrar, por favor contacte o seu administrador.",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" => "Os seus ficheiros estão encriptados. Se não activou a chave de recuperação, não vai ser possível recuperar os seus dados no caso da sua password ser reinicializada. Se não tem a certeza do que precisa de fazer, por favor contacte o seu administrador antes de continuar. Tem a certeza que quer continuar?",
"I know what I'm doing" => "Tenho a certeza",
"Reset password" => "Repor password",
"Password can not be changed. Please contact your administrator." => "A password não pode ser alterada. Contacte o seu administrador.",
"Yes" => "Sim",
"No" => "Não",
"Choose" => "Escolha",
"Error loading file picker template: {error}" => "Erro ao carregar o modelo de selecionador de ficheiro: {error}",
"Ok" => "Ok",
"Error loading message template: {error}" => "Erro ao carregar o template: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} conflicto de ficheiro","{count} conflitos de ficheiro"),
"One file conflict" => "Um conflito no ficheiro",
"New Files" => "Ficheiros Novos",
"Already existing files" => "Ficheiro já existente",
"Which files do you want to keep?" => "Quais os ficheiros que pretende manter?",
"If you select both versions, the copied file will have a number added to its name." => "Se escolher ambas as versões, o ficheiro copiado irá ter um número adicionado ao seu nome.",
"Cancel" => "Cancelar",
"Continue" => "Continuar",
"(all selected)" => "(todos seleccionados)",
"({count} selected)" => "({count} seleccionados)",
"Error loading file exists template" => "Erro ao carregar o modelo de existências do ficheiro",
"Very weak password" => "Password muito fraca",
"Weak password" => "Password fraca",
"So-so password" => "Password aceitável",
"Good password" => "Password Forte",
"Strong password" => "Password muito forte",
"Shared" => "Partilhado",
"Shared by {owner}" => "Partilhado por {owner}",
"Shared with {recipients}" => "Partilhado com {recipients}",
"Share" => "Partilhar",
"Error" => "Erro",
"Error while sharing" => "Erro ao partilhar",
"Error while unsharing" => "Erro ao deixar de partilhar",
"Error while changing permissions" => "Erro ao mudar permissões",
"Shared with you and the group {group} by {owner}" => "Partilhado consigo e com o grupo {group} por {owner}",
"Shared with you by {owner}" => "Partilhado consigo por {owner}",
"Share with user or group …" => "Partilhar com utilizador ou grupo...",
"Share link" => "Partilhar o link",
"The public link will expire no later than {days} days after it is created" => "O link público expira, o mais tardar {days} dias após sua criação",
"By default the public link will expire after {days} days" => "Por defeito, o link publico irá expirar depois de {days} dias",
"Password protect" => "Proteger com palavra-passe",
"Choose a password for the public link" => "Defina a palavra-passe para o link público",
"Allow Public Upload" => "Permitir Envios Públicos",
"Email link to person" => "Enviar o link por e-mail",
"Send" => "Enviar",
"Set expiration date" => "Especificar data de expiração",
"Expiration date" => "Data de expiração",
"Share via email:" => "Partilhar via email:",
"No people found" => "Não foi encontrado ninguém",
"group" => "grupo",
"Resharing is not allowed" => "Não é permitido partilhar de novo",
"Shared in {item} with {user}" => "Partilhado em {item} com {user}",
"Unshare" => "Deixar de partilhar",
"notify by email" => "Notificar por email",
"can share" => "pode partilhar",
"can edit" => "pode editar",
"access control" => "Controlo de acesso",
"create" => "criar",
"update" => "actualizar",
"delete" => "apagar",
"Password protected" => "Protegido com palavra-passe",
"Error unsetting expiration date" => "Erro ao retirar a data de expiração",
"Error setting expiration date" => "Erro ao aplicar a data de expiração",
"Sending ..." => "A Enviar...",
"Email sent" => "E-mail enviado",
"Warning" => "Aviso",
"The object type is not specified." => "O tipo de objecto não foi especificado",
"Enter new" => "Introduza novo",
"Delete" => "Eliminar",
"Add" => "Adicionar",
"Edit tags" => "Editar etiquetas",
"Error loading dialog template: {error}" => "Erro ao carregar modelo de diálogo: {error}",
"No tags selected for deletion." => "Não foram escolhidas etiquetas para apagar.",
"Updating {productName} to version {version}, this may take a while." => "A atualizar {productName} para a versão {version}, isto poderá demorar algum tempo.",
"Please reload the page." => "Por favor recarregue a página.",
"The update was unsuccessful." => "Não foi possível atualizar.",
"The update was successful. Redirecting you to ownCloud now." => "A actualização foi concluída com sucesso. Vai ser redireccionado para o ownCloud agora.",
"Couldn't reset password because the token is invalid" => "É impossível efetuar reset à password. ",
"Couldn't send reset email. Please make sure your username is correct." => "Ocorreu um problema com o envio do e-mail, por favor confirme o seu utilizador.",
"Couldn't send reset email because there is no email address for this username. Please contact your administrator." => "Ocorreu um problema com o envio do e-mail, por favor contacte o administrador.",
"%s password reset" => "%s reposição da password",
"Use the following link to reset your password: {link}" => "Use o seguinte endereço para repor a sua password: {link}",
"You will receive a link to reset your password via Email." => "Vai receber um endereço para repor a sua password",
"Username" => "Nome de utilizador",
"Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" => "Os seus ficheiros estão encriptados. Se não activou a chave de recuperação, não vai ser possível recuperar os seus dados no caso da sua password ser reinicializada. Se não tem a certeza do que precisa de fazer, por favor contacte o seu administrador antes de continuar. Tem a certeza que quer continuar?",
"Yes, I really want to reset my password now" => "Sim, tenho a certeza que pretendo redefinir a minha palavra-passe agora.",
"Reset" => "Repor",
"New password" => "Nova palavra-chave",
"New Password" => "Nova password",
"Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " => "Esta plataforma não suporta o sistema operativo Mac OS X e o %s poderá não funcionar correctamente. Utilize por sua conta e risco.",
"For the best results, please consider using a GNU/Linux server instead." => "Para um melhor resultado, utilize antes o servidor GNU/Linux.",
"Personal" => "Pessoal",
"Users" => "Utilizadores",
"Apps" => "Aplicações",
"Admin" => "Admin",
"Help" => "Ajuda",
"Error loading tags" => "Erro ao carregar etiquetas",
"Tag already exists" => "A etiqueta já existe",
"Error deleting tag(s)" => "Erro ao apagar etiqueta(s)",
"Error tagging" => "Erro ao etiquetar",
"Error untagging" => "Erro ao desetiquetar",
"Error favoriting" => "Erro a definir como favorito",
"Error unfavoriting" => "Erro a remover como favorito",
"Access forbidden" => "Acesso interdito",
"Cloud not found" => "Cloud nao encontrada",
"Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" => "Olá,\n\napenas para informar que %s partilhou »%s« consigo.\nConsulte aqui: %s\n",
"The share will expire on %s." => "Esta partilha vai expirar em %s.",
"Cheers!" => "Parabéns!",
"Security Warning" => "Aviso de Segurança",
"Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" => "A sua versão do PHP é vulnerável ao ataque Byte Null (CVE-2006-7243)",
"Please update your PHP installation to use %s securely." => "Por favor atualize a sua versão PHP instalada para usar o %s com segurança.",
"No secure random number generator is available, please enable the PHP OpenSSL extension." => "Não existe nenhum gerador seguro de números aleatórios, por favor, active a extensão OpenSSL no PHP.",
"Without a secure random number generator an attacker may be able to predict password reset tokens and take over your account." => "Sem nenhum gerador seguro de números aleatórios, uma pessoa mal intencionada pode prever a sua password, reiniciar as seguranças adicionais e tomar conta da sua conta. ",
"Your data directory and files are probably accessible from the internet because the .htaccess file does not work." => "A pasta de dados do ownCloud e os respectivos ficheiros, estarão provavelmente acessíveis a partir da internet, pois o ficheiros .htaccess não funciona.",
"For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." => "Para obter informações de como configurar correctamente o servidor, veja em: <a href=\"%s\" target=\"_blank\">documentação</a>.",
"Create an <strong>admin account</strong>" => "Criar uma <strong>conta administrativa</strong>",
"Password" => "Password",
"Storage & database" => "Armazenamento e base de dados",
"Data folder" => "Pasta de dados",
"Configure the database" => "Configure a base de dados",
"Only %s is available." => "Apenas %s está disponível.",
"Database user" => "Utilizador da base de dados",
"Database password" => "Password da base de dados",
"Database name" => "Nome da base de dados",
"Database tablespace" => "Tablespace da base de dados",
"Database host" => "Anfitrião da base de dados",
"SQLite will be used as database. For larger installations we recommend to change this." => "Será usado SQLite como base de dados. Para instalações maiores é recomendável a sua alteração.",
"Finish setup" => "Acabar instalação",
"Finishing …" => "A terminar...",
"This application requires JavaScript to be enabled for correct operation.  Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and re-load this interface." => "Esta aplicação requer JavaScript ativado para uma operação correta. Por favor <a href=\"http://enable-javascript.com/\" target=\"_blank\">ative o JavaScript</a> e recarregue esta interface.",
"%s is available. Get more information on how to update." => "%s está disponível. Tenha mais informações como actualizar.",
"Log out" => "Sair",
"Automatic logon rejected!" => "Login automático rejeitado!",
"If you did not change your password recently, your account may be compromised!" => "Se não mudou a sua palavra-passe recentemente, a sua conta pode ter sido comprometida!",
"Please change your password to secure your account again." => "Por favor mude a sua palavra-passe para assegurar a sua conta de novo.",
"Server side authentication failed!" => "Autenticação do lado do servidor falhou!",
"Please contact your administrator." => "Por favor contacte o administrador.",
"Forgot your password? Reset it!" => "Esqueceu-se da password? Recupere-a!",
"remember" => "lembrar",
"Log in" => "Entrar",
"Alternative Logins" => "Contas de acesso alternativas",
"Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" => "Olá,<br><br>apenas para informar que %s partilhou <strong>%s</strong> consigo.<br><a href=\"%s\">Consulte aqui!</a><br><br>",
"This ownCloud instance is currently in single user mode." => "Esta instância do ownCloud está actualmente configurada no modo de utilizador único.",
"This means only administrators can use the instance." => "Isto significa que apenas os administradores podem usar a instância.",
"Contact your system administrator if this message persists or appeared unexpectedly." => "Contacte o seu administrador de sistema se esta mensagem continuar a aparecer ou apareceu inesperadamente.",
"Thank you for your patience." => "Obrigado pela sua paciência.",
"%s will be updated to version %s." => "O %s irá ser atualizado para a versão %s.",
"The following apps will be disabled:" => "As seguintes apps irão ser desativadas:",
"The theme %s has been disabled." => "O tema %s foi desativado.",
"Please make sure that the database, the config folder and the data folder have been backed up before proceeding." => "Por favor garanta a cópia de segurança da base de dados e das pastas 'config' e 'data' antes de prosseguir.",
"Start update" => "Iniciar atualização",
"This ownCloud instance is currently being updated, which may take a while." => "Esta instância do ownCloud está a ser actualizada, poderá demorar algum tempo.",
"Please reload this page after a short time to continue using ownCloud." => "Por favo recarregue esta página após algum tempo para continuar a usar ownCloud.",
"To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" => "Para evitar tempos de espera com instalações maiores, você pode em vez disso, executar o seguinte comando a partir do diretório de instalação:",
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
